@@ -137,6 +137,22 @@ MapDisplay::MapDisplay()
   transform_timestamp_property_ = new rviz_common::properties::BoolProperty(
     "Use Timestamp", false,
     "Use map header timestamp when transforming", this, SLOT(transformMap()));
+
+  binary_view_property_ = new rviz_common::properties::BoolProperty(
+    "Binary representation",
+    false,
+    "Represent the map value as either free or occupied, considering the user-defined threshold",
+    this,
+    SLOT(updatePalette()));
+
+  binary_threshold_property_ = new rviz_common::properties::IntProperty(
+    "Binary threshold",
+    100,
+    "Minimum value to mark cells as obstacle in the binary representation of the map",
+    this,
+    SLOT(updateBinaryThreshold()));
+  binary_threshold_property_->setMin(0);
+  binary_threshold_property_->setMax(100);
 }
 
 MapDisplay::~MapDisplay()
@@ -182,15 +198,27 @@ void MapDisplay::onInitialize()
       this->update_profile_ = profile;
       updateMapUpdateTopic();
     });
+  int threshold = binary_threshold_property_->getInt();
   // Order of palette textures here must match option indices for color_scheme_property_ above.
   palette_textures_.push_back(makePaletteTexture(makeMapPalette()));
+  palette_textures_binary_.push_back(makePaletteTexture(makeMapPalette(true, threshold)));
   color_scheme_transparency_.push_back(false);
   palette_textures_.push_back(makePaletteTexture(makeCostmapPalette()));
+  palette_textures_binary_.push_back(makePaletteTexture(makeCostmapPalette(true, threshold)));
   color_scheme_transparency_.push_back(true);
   palette_textures_.push_back(makePaletteTexture(makeRawPalette()));
+  palette_textures_binary_.push_back(makePaletteTexture(makeRawPalette(true, threshold)));
   color_scheme_transparency_.push_back(true);
 }
 
+void MapDisplay::updateBinaryThreshold()
+{
+  int threshold = binary_threshold_property_->getInt();
+  palette_textures_binary_[0] = makePaletteTexture(makeMapPalette(true, threshold));
+  palette_textures_binary_[1] = makePaletteTexture(makeCostmapPalette(true, threshold));
+  palette_textures_binary_[2] = makePaletteTexture(makeRawPalette(true, threshold));
+}
+
 void MapDisplay::updateTopic()
 {
   update_topic_property_->setValue(topic_property_->getTopic() + "_updates");
@@ -360,9 +388,10 @@ void MapDisplay::updateMapDataInMemory(
   const map_msgs::msg::OccupancyGridUpdate::ConstSharedPtr update)
 {
   for (size_t y = 0; y < update->height; y++) {
+    auto offset = update->data.begin() + y * update->width;
     std::copy(
-      update->data.begin(),
-      update->data.begin() + update->width,
+      offset,
+      offset + update->width,
       current_map_.data.begin() + (update->y + y) * current_map_.info.width + update->x);
   }
 }
@@ -570,6 +599,8 @@ void MapDisplay::updateSwatches() const
 
 void MapDisplay::updatePalette()
 {
+  bool binary = binary_view_property_->getBool();
+
   int palette_index = color_scheme_property_->getOptionInt();
 
   for (const auto & swatch : swatches_) {
@@ -580,7 +611,11 @@ void MapDisplay::updatePalette()
     } else {
       palette_tex_unit = pass->createTextureUnitState();
     }
-    palette_tex_unit->setTexture(palette_textures_[palette_index]);
+    if (binary) {
+      palette_tex_unit->setTexture(palette_textures_binary_[palette_index]);
+    } else {
+      palette_tex_unit->setTexture(palette_textures_[palette_index]);
+    }
     palette_tex_unit->setTextureFiltering(Ogre::TFO_NONE);
   }
 
